==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/toolbox.cpp <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "toolbox.h"

ToolBox :: ToolBox(QWidget* parent/*=0*/)
    :QToolBar(parent)
{
        actionNouveau = new QAction(this);
        actionNouveau->setObjectName(QString::fromUtf8("actionNouveau"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/document-new.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionNouveau->setIcon(icon);
        actionSauver = new QAction(this);
        actionSauver->setObjectName(QString::fromUtf8("actionSauver"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/document-save.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionSauver->setIcon(icon1);
        actionOuvrir = new QAction(this);
        actionOuvrir->setObjectName(QString::fromUtf8("actionOuvrir"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/images/document-open.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionOuvrir->setIcon(icon2);
        actionQuitter = new QAction(this);
        actionQuitter->setObjectName(QString::fromUtf8("actionQuitter"));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/images/application-exit.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionQuitter->setIcon(icon3);
        actionGenerer = new QAction(this);
        actionGenerer->setObjectName(QString::fromUtf8("actionGenerer"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/images/run-build.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionGenerer->setIcon(icon4);
        actionApercu = new QAction(this);
        actionApercu->setObjectName(QString::fromUtf8("actionApercu"));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/images/document-preview.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionApercu->setIcon(icon5);
        actionExporterPdf = new QAction(this);
        actionExporterPdf->setObjectName(QString::fromUtf8("actionExporterPdf"));
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/images/document-export.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionExporterPdf->setIcon(icon6);
        actionAide = new QAction(this);
        actionAide->setObjectName(QString::fromUtf8("actionAide"));
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/images/help-about.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionAide->setIcon(icon7);

        actionNouveau->setText(QString::fromUtf8("Nouveau"));
        actionNouveau->setToolTip(QString::fromUtf8("Nouveau"));
        actionNouveau->setShortcut(Qt::CTRL+Qt::Key_N);
	
        actionSauver->setText(QString::fromUtf8("Sauver"));
        actionSauver->setToolTip(QString::fromUtf8("Sauver"));
        actionSauver->setShortcut(Qt::CTRL+Qt::Key_S);
	
        actionOuvrir->setText(QString::fromUtf8("Ouvrir"));
	actionOuvrir->setToolTip(QString::fromUtf8("Ouvrir"));
        actionOuvrir->setShortcut(Qt::CTRL+Qt::Key_O);
	
        actionQuitter->setText(QString::fromUtf8("Quitter"));
        actionQuitter->setToolTip(QString::fromUtf8("Quitter"));
        actionQuitter->setShortcut(Qt::CTRL+Qt::Key_Q);
	
        actionGenerer->setText(QString::fromUtf8("Générer"));
        actionGenerer->setToolTip(QString::fromUtf8("Générer"));
        actionGenerer->setShortcut(Qt::CTRL+Qt::Key_G);
	
        actionApercu->setText(QString::fromUtf8("Aperçu"));
        actionApercu->setToolTip(QString::fromUtf8("Aperçu"));
        actionApercu->setShortcut(Qt::Key_F1);
	
        actionExporterPdf->setText(QString::fromUtf8("Exporter Pdf"));
        actionExporterPdf->setToolTip(QString::fromUtf8("Exporter en pdf"));
        actionExporterPdf->setShortcut(Qt::CTRL+Qt::Key_P);
	
        actionAide->setText(QString::fromUtf8("Aide"));
        actionAide->setToolTip(QString::fromUtf8("Aide"));
	
	
	
        setObjectName(QString::fromUtf8("toolBar"));
        setMovable(false);
        setAllowedAreas(Qt::RightToolBarArea);
        setIconSize(QSize(48, 48));
        setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
	setOrientation(Qt::Vertical);
        setFloatable(false);

        addAction(actionNouveau);
        addAction(actionOuvrir);
        addAction(actionSauver);
        addAction(actionAide);
        addAction(actionQuitter);
        addSeparator();
        addAction(actionGenerer);
        addAction(actionApercu);
        addAction(actionExporterPdf);

}
ToolBox :: ~ToolBox()
{
 
}

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/toolbox.cpp <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#include "toolbox.h"

ToolBox :: ToolBox(QWidget* parent/*=0*/)
    :QToolBar(parent)
{
        actionNouveau = new QAction(this);
        actionNouveau->setObjectName(QString::fromUtf8("actionNouveau"));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/document-new.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionNouveau->setIcon(icon);
        actionSauver = new QAction(this);
        actionSauver->setObjectName(QString::fromUtf8("actionSauver"));
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/document-save.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionSauver->setIcon(icon1);
        actionOuvrir = new QAction(this);
        actionOuvrir->setObjectName(QString::fromUtf8("actionOuvrir"));
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/images/document-open.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionOuvrir->setIcon(icon2);
        actionQuitter = new QAction(this);
        actionQuitter->setObjectName(QString::fromUtf8("actionQuitter"));
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/images/application-exit.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionQuitter->setIcon(icon3);
        actionGenerer = new QAction(this);
        actionGenerer->setObjectName(QString::fromUtf8("actionGenerer"));
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/images/run-build.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionGenerer->setIcon(icon4);
        actionApercu = new QAction(this);
        actionApercu->setObjectName(QString::fromUtf8("actionApercu"));
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/images/document-preview.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionApercu->setIcon(icon5);
        actionExporterPdf = new QAction(this);
        actionExporterPdf->setObjectName(QString::fromUtf8("actionExporterPdf"));
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/images/document-export.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionExporterPdf->setIcon(icon6);
        actionAide = new QAction(this);
        actionAide->setObjectName(QString::fromUtf8("actionAide"));
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/images/help-about.png"), QSize(), QIcon::Normal, QIcon::Off);
        actionAide->setIcon(icon7);

        actionNouveau->setText(QString::fromUtf8("Nouveau"));
        actionNouveau->setToolTip(QString::fromUtf8("Nouveau"));
        actionNouveau->setShortcut(Qt::CTRL | Qt::Key_N);
	
        actionSauver->setText(QString::fromUtf8("Sauver"));
        actionSauver->setToolTip(QString::fromUtf8("Sauver"));
        actionSauver->setShortcut(Qt::CTRL | Qt::Key_S);
	
        actionOuvrir->setText(QString::fromUtf8("Ouvrir"));
	actionOuvrir->setToolTip(QString::fromUtf8("Ouvrir"));
        actionOuvrir->setShortcut(Qt::CTRL | Qt::Key_O);
	
        actionQuitter->setText(QString::fromUtf8("Quitter"));
        actionQuitter->setToolTip(QString::fromUtf8("Quitter"));
        actionQuitter->setShortcut(Qt::CTRL | Qt::Key_Q);
	
        actionGenerer->setText(QString::fromUtf8("Générer"));
        actionGenerer->setToolTip(QString::fromUtf8("Générer"));
        actionGenerer->setShortcut(Qt::CTRL | Qt::Key_G);
	
        actionApercu->setText(QString::fromUtf8("Aperçu"));
        actionApercu->setToolTip(QString::fromUtf8("Aperçu"));
        actionApercu->setShortcut(Qt::Key_F1);
	
        actionExporterPdf->setText(QString::fromUtf8("Exporter Pdf"));
        actionExporterPdf->setToolTip(QString::fromUtf8("Exporter en pdf"));
        actionExporterPdf->setShortcut(Qt::CTRL | Qt::Key_P);
	
        actionAide->setText(QString::fromUtf8("Aide"));
        actionAide->setToolTip(QString::fromUtf8("Aide"));
	
	
	
        setObjectName(QString::fromUtf8("toolBar"));
        setMovable(false);
        setAllowedAreas(Qt::RightToolBarArea);
        setIconSize(QSize(48, 48));
        setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
	setOrientation(Qt::Vertical);
        setFloatable(false);

        addAction(actionNouveau);
        addAction(actionOuvrir);
        addAction(actionSauver);
        addAction(actionAide);
        addAction(actionQuitter);
        addSeparator();
        addAction(actionGenerer);
        addAction(actionApercu);
        addAction(actionExporterPdf);

}
ToolBox :: ~ToolBox()
{
 
}
